@@ -1,9 +1,10 @@
+from typing import Optional
 import nonebot
 from pydantic import BaseModel, Extra
 
 
 class Config(BaseModel, extra=Extra.ignore):
-    github_token : str
+    github_token : Optional[str] = None
 
 global_config = nonebot.get_driver().config
 githubcard_config = Config(**global_config.dict())
\ No newline at end of file
